@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,37 +12,18 @@
 #ifndef ARRAYDIALOG_H
 #define ARRAYDIALOG_H
 
+#include "ui_arraydialog.h"
 
-#include <qspinbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcombobox.h>
-#include <qtable.h>
-#include <qpushbutton.h>
-#include <qdialog.h>
-
-
-class arraydialog : public QDialog  {
+class ArrayDialog : public QDialog  {
    Q_OBJECT
 public:
-	arraydialog(QWidget *parent=0, const char *name=0);
-	~arraydialog();
-
-public:
-  QTable* Table1;
-	QSpinBox *spinBoxRows;
-	QSpinBox *spinBoxCollums;
-	QLabel *QLabel_1;
-	QLabel *QLabel_2;
-	QLabel *QLabel_3;
-  QLabel *QLabel_4;
-  QComboBox *combo, *combo2;
-	QPushButton *buttonOk;
-	QPushButton *buttonCancel;
+	ArrayDialog(QWidget *parent=0, const char *name=0);
+	~ArrayDialog();
+	Ui::ArrayDialog ui;
 
 protected slots:
   void NewRows(int num);
-  void NewCollums(int num);
+  void NewColumns(int num);
 };
 
 
