@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,30 +12,14 @@
 #ifndef TABBINGDIALOG_H
 #define TABBINGDIALOG_H
 
-#include <qwidget.h>
-#include <qspinbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qdialog.h>
-#include <qlineedit.h>
+#include "ui_tabbingdialog.h"
 
-/**
-  *@author Pascal Brachet
-  */
-
-class tabbingdialog : public QDialog  {
+class TabbingDialog : public QDialog  {
    Q_OBJECT
 public: 
-	tabbingdialog(QWidget *parent=0, const char *name=0);
-	~tabbingdialog();
-
-public:
-	QSpinBox *spinBoxCollums, *spinBoxRows;
-	QLabel *Label1, *Label2, *Label3;
-  QLineEdit *LineEdit1;
-	QPushButton *buttonOk;
-	QPushButton *buttonCancel;
+	TabbingDialog(QWidget *parent=0, const char *name=0);
+	~TabbingDialog();
+	Ui::TabbingDialog ui;
 };
 
 #endif
