@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,43 +12,32 @@
 #ifndef USERMENUDIALOG_H
 #define USERMENUDIALOG_H
 
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
-#include <qdialog.h>
-#include <qpushbutton.h>
-#include <qstring.h>
+#include <QString>
+#include "ui_usermenudialog.h"
 
 typedef QString userlist[10];
 
-class usermenudialog : public QDialog
+class UserMenuDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    usermenudialog( QWidget* parent = 0, const char* name = 0);
-    ~usermenudialog();
+    UserMenuDialog( QWidget* parent = 0, QString name="");
+    ~UserMenuDialog();
+    Ui::UserMenuDialog ui;
 
     userlist Name,Tag;
 
 private:
     int previous_index;
-    QLineEdit *tagedit;
-    QLineEdit *itemedit;
-    QComboBox *combo1;
-    QLabel* label1;
-    QLabel* label2;
-	  QPushButton *buttonOk;
-	  QPushButton *buttonCancel;
 
 public slots:
-    void init();        
+    void init();
 
 private slots:
     void change(int index);
     void slotOk();
-
+    void updateItem();
 };
 
 #endif // USERMENUDIALOG_H
